package sun.management.snmp.util;

import java.util.logging.Level;
import java.util.logging.Logger;

public class MibLogger
{
    final Logger logger;
    final String className;
    
    static String getClassName(Class<?> clazz) {
        if (clazz == null) {
            return null;
        }
        if (clazz.isArray()) {
            return getClassName(clazz.getComponentType()) + "[]";
        }
        String name = clazz.getName();
        int lastIndex = name.lastIndexOf(46);
        int length = name.length();
        if (lastIndex < 0 || lastIndex >= length) {
            return name;
        }
        return name.substring(lastIndex + 1, length);
    }
    
    static String getLoggerName(Class<?> clazz) {
        if (clazz == null) {
            return "sun.management.snmp.jvminstr";
        }
        Package package1 = clazz.getPackage();
        if (package1 == null) {
            return "sun.management.snmp.jvminstr";
        }
        String name = package1.getName();
        if (name == null) {
            return "sun.management.snmp.jvminstr";
        }
        return name;
    }
    
    public MibLogger(Class<?> clazz) {
        this(getLoggerName(clazz), getClassName(clazz));
    }
    
    public MibLogger(Class<?> clazz, String str) {
        this(getLoggerName(clazz) + ((str == null) ? "" : ("." + str)), getClassName(clazz));
    }
    
    public MibLogger(String s) {
        this("sun.management.snmp.jvminstr", s);
    }
    
    public MibLogger(String name, String className) {
        Logger logger = null;
        try {
            logger = Logger.getLogger(name);
        }
        catch (Exception ex) {}
        this.logger = logger;
        this.className = className;
    }
    
    protected Logger getLogger() {
        return this.logger;
    }
    
    public boolean isTraceOn() {
        Logger logger = this.getLogger();
        return logger != null && logger.isLoggable(Level.FINE);
    }
    
    public boolean isDebugOn() {
        Logger logger = this.getLogger();
        return logger != null && logger.isLoggable(Level.FINEST);
    }
    
    public boolean isInfoOn() {
        Logger logger = this.getLogger();
        return logger != null && logger.isLoggable(Level.INFO);
    }
    
    public boolean isConfigOn() {
        Logger logger = this.getLogger();
        return logger != null && logger.isLoggable(Level.CONFIG);
    }
    
    public void config(String sourceMethod, String msg) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.CONFIG, this.className, sourceMethod, msg);
        }
    }
    
    public void config(String sourceMethod, Throwable thrown) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.CONFIG, this.className, sourceMethod, thrown.toString(), thrown);
        }
    }
    
    public void config(String sourceMethod, String msg, Throwable thrown) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.CONFIG, this.className, sourceMethod, msg, thrown);
        }
    }
    
    public void error(String sourceMethod, String msg) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.SEVERE, this.className, sourceMethod, msg);
        }
    }
    
    public void info(String sourceMethod, String msg) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.INFO, this.className, sourceMethod, msg);
        }
    }
    
    public void info(String sourceMethod, Throwable thrown) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.INFO, this.className, sourceMethod, thrown.toString(), thrown);
        }
    }
    
    public void info(String sourceMethod, String msg, Throwable thrown) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.INFO, this.className, sourceMethod, msg, thrown);
        }
    }
    
    public void warning(String sourceMethod, String msg) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.WARNING, this.className, sourceMethod, msg);
        }
    }
    
    public void warning(String sourceMethod, Throwable thrown) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.WARNING, this.className, sourceMethod, thrown.toString(), thrown);
        }
    }
    
    public void warning(String sourceMethod, String msg, Throwable thrown) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.WARNING, this.className, sourceMethod, msg, thrown);
        }
    }
    
    public void trace(String sourceMethod, String msg) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.FINE, this.className, sourceMethod, msg);
        }
    }
    
    public void trace(String sourceMethod, Throwable thrown) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.FINE, this.className, sourceMethod, thrown.toString(), thrown);
        }
    }
    
    public void trace(String sourceMethod, String msg, Throwable thrown) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.FINE, this.className, sourceMethod, msg, thrown);
        }
    }
    
    public void debug(String sourceMethod, String msg) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.FINEST, this.className, sourceMethod, msg);
        }
    }
    
    public void debug(String sourceMethod, Throwable thrown) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.FINEST, this.className, sourceMethod, thrown.toString(), thrown);
        }
    }
    
    public void debug(String sourceMethod, String msg, Throwable thrown) {
        Logger logger = this.getLogger();
        if (logger != null) {
            logger.logp(Level.FINEST, this.className, sourceMethod, msg, thrown);
        }
    }
}
